#!/usr/bin/env python3.7
# -*- coding: utf-8 -*-
"""
  CDBI	Mars 2022
  Sélection Auto 1 ou 2 Capteurs BME280
Transfert des données par le fichier Thermo.dat
	0=Heure
	1=Config du capteur
	2=Pression hpa
	3=Pression cm
	4=Humidite
	5=Temperature
	6=Alarme Temperature
	7=Localisation
ENR MIN/MIN
	Fichier ThermoMM.dat
	0=Temp Min
	1=Date
	2=Heure
	3=Temp Max
	4=date
	5=heure
"""

import os,sys
from time import sleep
import time
from datetime import datetime
from tkinter import *
from tkinter import messagebox
import subprocess
from subprocess import call
import pickle
import RPi.GPIO as GPIO

ver='Thermo2-BME-2.0.1'

"""Librairie générale"""
sys.path.append (sys.path[0] + "/Lib")

""" On regarde si BME280 present en ad1 et ad2"""
ad1=0x76
ad2=0x77
flagBME=0
"""On regarde si BME280 présent en ad1 par défaut"""
from Lib import bme280driver
try:
	Capteur1=bme280driver.BME280(ad1)
	#Capteur1.CORtemp(0.0)
	flagBME=1
	print ("BME280-" + str(ad1))
except:
	print ("Pas de BME280 " + str(ad1))

if flagBME == 1:
	try:
		Capteur2=bme280driver.BME280(ad2)
		#Capteur2.CORtemp(0.0)
		flagBME=2
		print ("BME280-" + str(ad2))
	except:
		print ("Pas de BME280 " + str(ad2))

def config_GPIO():
	global V1,V2
	GPIO.setmode(GPIO.BCM)
	GPIO.setwarnings(False)
	V1=13
	GPIO.setup(V1,GPIO.OUT,initial=GPIO.LOW)
	V2=19
	GPIO.setup(V2,GPIO.OUT,initial=GPIO.LOW)
	
def Taillescreen():
	sc=os.popen("xrandr -q -d :0").readlines(1)[0]
	w=sc.split()[7]
	h=sc.split()[9][:-1]
	return w,h
	
def Get_Nom():
	r = str(subprocess.check_output("hostname", shell=True).decode('utf-8'))
	return r[:len(r)-1]

def Lire_BME280_1(histo):
	global Tmin1,Tmax1,flagBME
	uP=1
	data_all = Capteur1.read_all()
	if data_all == False:
		labCaptP1[0].config(text="****")
		labCaptP2[0].config(text="ERREUR-CAPTEUR")
		labCaptH[0].config(text="****")
		labCaptT[0].config(text="****")
		labHeure[0].config(text="****")
		if os.path.exists(FichDAT1):
			cmd="rm " + FichDAT1
			call (cmd,shell=True)
		return
	h=datetime.now().strftime('%H:%M:%S')
	d=datetime.now().strftime('%d/%m/%Y')
	labHeure[0].config(text=h)
	labCaptP1[0].config(text=str(("%5.2f hPa") % data_all.pressure[0]))
	labCaptP2[0].config(text=str(("%5.2f cm") % data_all.pressure[1]))
	labCaptH[0].config(text=str("%5.1f %%Hr" % data_all.humidity))
	labCaptT[0].config(text=str("%5.1f °C" % data_all.temperature))
	T=float("%5.1f" % data_all.temperature)
	if T < Tmin1[0]:
		Tmin1[0]=T
		Tmin1[1]=d
		Tmin1[2]=h
	if T > Tmax1[0]:
		Tmax1[0]=T
		Tmax1[1]=d
		Tmax1[2]=h
	labMIN[0].config(text="Tmin: " + str(Tmin1[0]))
	labDmin[0].config(text=Tmin1[1])
	labHmin[0].config(text=Tmin1[2])
	labMAX[0].config(text="Tmax: " + str(Tmax1[0]))
	labDmax[0].config(text=Tmax1[1])
	labHmax[0].config(text=Tmax1[2])
	fen1.update()

	d=datetime.now().strftime('%H:%M:%S')
	d+='|Cy' + str(Cycle.get())
	if chkHISTO1.get():
		d+="/H" + nbhHISTO1.get() + "/T" + str(corT1.get()) + ":" + str(AlaT1.get())
	else:
		d+="/H0/T" + str(corT1.get()) + ":" + str(AlaT1.get())
	d+='|' + str(float(("%5.2f") % data_all.pressure[0]))
	d+='|' + str(float(("%5.2f") % data_all.pressure[1]))
	d+='|' + str(float(("%5.1f") % data_all.humidity))
	d+='|' + str(float(("%5.1f") % data_all.temperature))
	""" Enr Alarme"""
	if float(AlaT1.get()) < 0:
		if float(data_all.temperature) > float(AlaT1.get()):
			d+='|' + str(1)
			labCaptT[0].config(fg='magenta')
			GPIO.output(V1,GPIO.HIGH)
		else:
			d+='|' + str(0)
			labCaptT[0].config(fg='blue')
			GPIO.output(V1,GPIO.LOW)
	else:
		if float(data_all.temperature) < float(AlaT1.get()):
			d+='|' + str(1)
			labCaptT[0].config(fg='magenta')
			GPIO.output(V1,GPIO.HIGH)
		else:
			d+='|' + str(0)
			labCaptT[0].config(fg='blue')
			GPIO.output(V1,GPIO.LOW)
	d+='|' + str(Loca1.get())
	with open(FichDAT1,'w') as nF:
		nF.write(str(d))
	"""ENR Min/Max"""
	d= str(Tmin1[0])
	d+='|' + str(Tmin1[1])
	d+='|' + str(Tmin1[2])
	d+='|' + str(Tmax1[0])
	d+='|' + str(Tmax1[1])
	d+='|' + str(Tmax1[2])
	with open(FichMM1,'w') as nF:
		nF.write(str(d) + "\n")

	if histo:
		d=datetime.now().strftime('%Y/%m')
		d+='|' + datetime.now().strftime('%d-%H:%M:%S')
		d+='|' + str(float(("%5.2f") % data_all.pressure[0]))
		d+='|' + str(float(("%5.1f") % data_all.humidity))
		d+='|' + str(float(("%5.1f") % data_all.temperature))
		with open(FichHISTO1,'a') as nF:
			nF.write(d +'\n')

def Lire_BME280_2(histo):
	global Tmin2,Tmax2,flagBME
	uP=1
	data_all = Capteur2.read_all()
	if data_all == False:
		labCaptP1[1].config(text="****")
		labCaptP2[1].config(text="ERREUR-CAPTEUR")
		labCaptH[1].config(text="****")
		labCaptT[1].config(text="****")
		labHeure[1].config(text="****")
		if os.path.exists(FichDAT2):
			cmd="rm " + FichDAT2
			call (cmd,shell=True)
		return
	h=datetime.now().strftime('%H:%M:%S')
	d=datetime.now().strftime('%d/%m/%Y')
	labHeure[1].config(text=h)
	labCaptP1[1].config(text=str(("%5.2f hPa") % data_all.pressure[0]))
	labCaptP2[1].config(text=str(("%5.2f cm") % data_all.pressure[1]))
	labCaptH[1].config(text=str("%5.1f %%Hr" % data_all.humidity))
	labCaptT[1].config(text=str("%5.1f °C" % data_all.temperature))
	T=float("%5.1f" % data_all.temperature)
	if T < Tmin2[0]:
		Tmin2[0]=T
		Tmin2[1]=d
		Tmin2[2]=h
	if T > Tmax2[0]:
		Tmax2[0]=T
		Tmax2[1]=d
		Tmax2[2]=h
	labMIN[1].config(text="Tmin: " + str(Tmin2[0]))
	labDmin[1].config(text=Tmin2[1])
	labHmin[1].config(text=Tmin2[2])
	labMAX[1].config(text="Tmax: " + str(Tmax2[0]))
	labDmax[1].config(text=Tmax2[1])
	labHmax[1].config(text=Tmax2[2])
	fen1.update()

	d=datetime.now().strftime('%H:%M:%S')
	d+='|Cy' + str(Cycle.get())
	if chkHISTO2.get():
		d+="/H" + nbhHISTO2.get() + "/T" + str(corT2.get()) + ":" + str(AlaT2.get())
	else:
		d+="/H0/T" + str(corT2.get()) + ":" + str(AlaT2.get())
	d+='|' + str(float(("%5.2f") % data_all.pressure[0]))
	d+='|' + str(float(("%5.2f") % data_all.pressure[1]))
	d+='|' + str(float(("%5.1f") % data_all.humidity))
	d+='|' + str(float(("%5.1f") % data_all.temperature))
	if float(AlaT2.get()) < 0:
		if float(data_all.temperature) > float(AlaT2.get()):
			d+='|' + str(1)
			labCaptT[1].config(fg='magenta')
			GPIO.output(V2,GPIO.HIGH)
		else:
			d+='|' + str(0)
			labCaptT[1].config(fg='blue')
			GPIO.output(V2,GPIO.LOW)
	else:
		if float(data_all.temperature) < float(AlaT2.get()):
			d+='|' + str(1)
			labCaptT[1].config(fg='magenta')
			GPIO.output(V2,GPIO.HIGH)
		else:
			d+='|' + str(0)
			labCaptT[1].config(fg='blue')
			GPIO.output(V2,GPIO.LOW)
	d+='|' + str(Loca2.get())
	with open(FichDAT2,'w') as nF:
		nF.write(str(d))
	"""ENR Min/Max"""
	d= str(Tmin2[0])
	d+='|' + str(Tmin2[1])
	d+='|' + str(Tmin2[2])
	d+='|' + str(Tmax2[0])
	d+='|' + str(Tmax2[1])
	d+='|' + str(Tmax2[2])
	with open(FichMM2,'w') as nF:
		nF.write(str(d) + "\n")

	if histo:
		d=datetime.now().strftime('%Y/%m')
		d+='|' + datetime.now().strftime('%d-%H:%M:%S')
		d+='|' + str(float(("%5.2f") % data_all.pressure[0]))
		d+='|' + str(float(("%5.1f") % data_all.humidity))
		d+='|' + str(float(("%5.1f") % data_all.temperature))
		with open(FichHISTO2,'a') as nF:
			nF.write(d +'\n')

def Fermer():
	global flagRUN
	#ENR_Config()
	if os.path.exists(FichDAT1):
		cmd="rm " + FichDAT1
		call (cmd,shell=True)
	if os.path.exists(FichDAT2):
		cmd="rm " + FichDAT2
		call (cmd,shell=True)
	flagRUN=False
	GPIO.cleanup()
	exit(200)

def ENR_Config():
	nF=open(FichierConf,'wb')
	ConfDATA= {
		'cycle': Cycle.get(),
		'cort1' :corT1.get(),
		'alat1' :AlaT1.get(),
		'histo1' :chkHISTO1.get(),
		'nbh1' :nbhHISTO1.get(),
		'loca1' :Loca1.get(),
		'cort2' :corT2.get(),
		'alat2' :AlaT2.get(),
		'histo2' :chkHISTO2.get(),
		'nbh2' :nbhHISTO2.get(),
		'loca2' :Loca2.get(),
		}
	pickle.dump(ConfDATA,nF)
	nF.close()

def LIRE_Config():
	global CycleHISTO1,CycleHISTO2
	global Tmin1,Tmax1,Tmin2,Tmax2
	if os.path.exists(FichierConf):
		nF=open(FichierConf,'rb')
		ConfDATA=pickle.load(nF)
		nF.close()
		Cycle.set(ConfDATA['cycle'])
		corT1.set(ConfDATA['cort1'])
		AlaT1.set(ConfDATA['alat1'])
		chkHISTO1.set(ConfDATA['histo1'])
		nbhHISTO1.set(ConfDATA['nbh1'])
		Loca1.set(ConfDATA['loca1'])
		corT2.set(ConfDATA['cort2'])
		AlaT2.set(ConfDATA['alat2'])
		chkHISTO2.set(ConfDATA['histo2'])
		nbhHISTO2.set(ConfDATA['nbh2'])
		Loca2.set(ConfDATA['loca2'])
		nF.close()
		if flagBME == 1:
			Capteur1.CORtemp(float(corT1.get()))
		if flagBME == 2:
			Capteur1.CORtemp(float(corT1.get()))
			Capteur2.CORtemp(float(corT2.get()))
		if Loca1.get() == "":Loca1.set("Description1 ?")
		if Loca2.get() == "":Loca2.set("Description2 ?")
		"""ENR dans Histo selon le cycle et le nombre par heure"""
		CycleHISTO1=int(3600/int(nbhHISTO1.get())/Cycle.get())
		CycleHISTO2=int(3600/int(nbhHISTO2.get())/Cycle.get())
		
		Tmin1=[50,"",""]
		Tmax1=[-50,"",""]
		if os.path.exists(FichMM1):
			with open(FichMM1,'r') as nF:
				l=nF.readline()
				l=l.split('|')
				Tmin1[0]=float(l[0])
				Tmin1[1]=l[1]
				Tmin1[2]=l[2]
				Tmax1[0]=float(l[3])
				Tmax1[1]=l[4]
				Tmax1[2]=l[5]

		if os.path.exists(FichMM2):
			Tmin2=[50,"",""]
			Tmax2=[-50,"",""]
			with open(FichMM2,'r') as nF:
				l=nF.readline()
				l=l.split('|')
				Tmin2[0]=float(l[0])
				Tmin2[1]=l[1]
				Tmin2[2]=l[2]
				Tmax2[0]=float(l[3])
				Tmax2[1]=l[4]
				Tmax2[2]=l[5]
			
			
			
		return True
	else:
		Cycle.set(20)
		corT1.set("0")
		AlaT1.set("19")
		nbhHISTO1.set(2)
		chkHISTO1.set(0)
		corT2.set("0")
		AlaT2.set("19")
		nbhHISTO2.set(2)
		chkHISTO2.set(0)
		CycleHISTO1=int(3600/int(nbhHISTO1.get())/Cycle.get())
		CycleHISTO2=int(3600/int(nbhHISTO2.get())/Cycle.get())
		return False

def Valid():
	ENR_Config()
	sleep(0.1)
	if LIRE_Config():
		bouENR.config(fg='darkgreen')
	else:
		bouENR.config(fg='darkred')

def RAZ1():
	global Tmin1,Tmax1
	Tmin1=[50,"",""]
	Tmax1=[-50,"",""]
	labMIN[0].config(text="Tmin------")
	labDmin[0].config(text="****")
	labHmin[0].config(text="****")
	labMAX[0].config(text="Tmax------")
	labDmax[0].config(text="****")
	labHmax[0].config(text="****")

def RAZ2():
	global Tmin2,Tmax2
	Tmin2=[50,"",""]
	Tmax2=[-50,"",""]
	labMIN[1].config(text="Tmin------")
	labDmin[1].config(text="****")
	labHmin[1].config(text="****")
	labMAX[1].config(text="Tmax------")
	labDmax[1].config(text="****")
	labHmax[1].config(text="****")

def Voyant(coul):
	can0.itemconfigure(voy,fill=coul)
	can0.update()

def Dessine_Principale(w,h):
	global can0,can2,can3,voy,labInf
	global labCaptP1,labCaptP2,labCaptH,labCaptT,labHeure
	global labHmin,labHmax,labDmin,labDmax,labMIN,labMAX
	global listMH,bouENR
	fra=[]
	labP1=[]
	labInf=[]
	labP2=[]
	labCY=[]
	EntreeCY=[]
	labHU=[]
	labCorT=[]
	EntreeCorT=[]
	labAlaT=[]
	EntreeAlaT=[]
	labT=[]
	labH=[]
	labMIN=[]
	labDmin=[]
	labHmin=[]
	labMAX=[]
	labDmax=[]
	labHmax=[]
	
	labCaptP1=[]
	labCaptP2=[]
	labCaptH=[]
	labCaptT=[]
	labHeure=[]
	listMH=[]
	bouRAZ=[]
	CheckHISTO=[]
	labNBH=[]
	labLOC=[]
	EntreeLOC=[]
	nbh1=[]
	nbh2=[]
	nbh4=[]
	nbh6=[]

	fen1.geometry(str(w) + "x" + str(h) + '+' + str(int((scrW-w)/2)) + '+' + str(int((scrH-h)/3)))
	fen1.config(bg='lightblue')
	fen1.title(Get_Nom() + " >> " +ver)

	can2 = Canvas(fen1,bg='lightyellow',bd=1)
	can2.configure(relief='solid',width=480,height=230)
	can2.place(x=5,y=5)

	can0 = Canvas(fen1,bg='lightgrey',bd=1)
	can0.configure(relief='solid',width=w-20,height=30)
	can0.place(x=5,y=h-40)

	bouENR= Button(can0,text="ENR Config",command=Valid,fg='blue')
	bouENR.place(x=10,y=5,height=25)
	labCY=Label(can0,text='Cycle (s)',bg='lightgrey',fg='black',font=('Arial',10))
	labCY.place(x=125,y=5)
	EntreeCY=Spinbox(can0,from_=15,to=300,textvariable=Cycle,width=3)
	EntreeCY.place(x=185,y=5,height=25)
	voy=can0.create_oval(235,10,255,25,width=2,fill='magenta')
	labCHE=Label(can0,text=che[1],bg='lightgrey',fg='black',font=('Arial',10))
	labCHE.place(x=265,y=5)
	
	tx=5
	ty=5
	labP1.append(Label(can2,text='Pression:',bg='lightyellow',fg='blue',font=('Arial',12)))
	labP1[0].place(x=tx,y=ty+2)
	labCaptP1.append(Label(can2,bg='lightyellow',fg='blue',font=('Arial',18)))
	labCaptP1[0].place(x=tx+95,y=ty)
	labInf.append(Label(can2,text='Capteur',bg='lightyellow',fg='black',font=('Arial',12,'bold')))
	labInf[0].place(x=260,y=ty+2)

	ty+=30
	labP2.append(Label(can2,text='Pression:',bg='lightyellow',fg='blue',font=('Arial',12)))
	labP2[0].place(x=tx,y=ty+2)
	labCaptP2.append(Label(can2,bg='lightyellow',fg='blue',font=('Arial',18)))
	labCaptP2[0].place(x=tx+95,y=ty)

	ty+=30
	labHU.append(Label(can2,text='Humidité-Rel:',bg='lightyellow',fg='blue',font=('Arial',12)))
	labHU[0].place(x=tx,y=ty+2)
	labCaptH.append(Label(can2,bg='lightyellow',fg='blue',font=('Arial',18)))
	labCaptH[0].place(x=tx+95,y=ty)
	labCorT.append(Label(can2,text='CorTemp',bg='lightyellow',fg='black',font=('Arial',10)))
	labCorT[0].place(x=260,y=ty)
	EntreeCorT.append(Spinbox(can2,from_=-5,to=5,textvariable=corT1,width=3))
	EntreeCorT[0].place(x=330,y=ty,height=25)
	labAlaT.append(Label(can2,text='Alarme # T',bg='lightyellow',fg='black',font=('Arial',10)))
	labAlaT[0].place(x=260,y=ty+30)
	EntreeAlaT.append(Spinbox(can2,from_=-20,to=30,textvariable=AlaT1,width=3))
	EntreeAlaT[0].place(x=330,y=ty+30,height=25)

	ty+=30
	labT.append(Label(can2,text='Température:',bg='lightyellow',fg='blue',font=('Arial',12)))
	labT[0].place(x=tx,y=ty+2)
	labCaptT.append(Label(can2,bg='lightyellow',fg='blue',font=('Arial',18)))
	labCaptT[0].place(x=tx+95,y=ty)

	ty+=30
	labH.append(Label(can2,text='Heure:',bg='lightyellow',fg='blue',font=('Arial',12)))
	labH[0].place(x=tx,y=ty+2)
	labHeure.append(Label(can2,bg='lightyellow',fg='blue',font=('Arial',18)))
	labHeure[0].place(x=tx+95,y=ty)
	
	ty+=35
	labLOC.append(Label(can2,text='Localisation:',bg='lightyellow',fg='blue',font=('Arial',12)))
	labLOC[0].place(x=tx,y=ty)
	EntreeLOC.append(Entry(can2,textvariable=Loca1,font=("Arial",10),width=20,bg="lightyellow"))
	EntreeLOC[0].place(x=tx+105,y=ty)
	EntreeLOC[0].config(relief='flat')

	ty+=30
	can2.create_line(10,ty,470,ty,width=2,fill='grey')
	labMIN.append(Label(can2,text='MIN: ----',bg='lightyellow',fg='green',font=('Arial',12)))
	labMIN[0].place(x=10,y=ty+7)
	labDmin.append(Label(can2,text='----',bg='lightyellow',fg='green',font=('Arial',10)))
	labDmin[0].place(x=100,y=ty+2)
	labHmin.append(Label(can2,text='----',bg='lightyellow',fg='green',font=('Arial',10)))
	labHmin[0].place(x=100,y=ty+17)
	labMAX.append(Label(can2,text='MAX: ----',bg='lightyellow',fg='green',font=('Arial',12)))
	labMAX[0].place(x=190,y=ty+7)
	labDmax.append(Label(can2,text='----',bg='lightyellow',fg='green',font=('Arial',10)))
	labDmax[0].place(x=285,y=ty+2)
	labHmax.append(Label(can2,text='----',bg='lightyellow',fg='green',font=('Arial',10)))
	labHmax[0].place(x=285,y=ty+17)

	bouRAZ.append(Button(can2,text="RAZ-1",command=RAZ1,font=('Arial',10)))
	bouRAZ[0].place(x=390,y=ty+8,height=20)

	fra.append(LabelFrame(can2,text="HISTO",width=80,height=145,borderwidth=1,relief='solid',bg='lightyellow',fg='black',font=('Arial',10)))
	fra[0].place(x=390,y=8)
	CheckHISTO.append(Checkbutton(fra[0],text="Histo",variable=chkHISTO1,bg='lightyellow'))
	CheckHISTO[0].place(x=2,y=2)
	labNBH.append(Label(fra[0],text='Nb/Heure',bg='lightyellow',fg='black',font=('Arial',10)))
	labNBH[0].place(x=2,y=22)
	nbh1.append(Radiobutton(fra[0],text="1 (60')",variable=nbhHISTO1,value=1,bg='lightyellow'))
	nbh1[0].place(x=0,y=40)
	nbh2.append(Radiobutton(fra[0],text="2 (30')",variable=nbhHISTO1,value=2,bg='lightyellow'))
	nbh2[0].place(x=0,y=60)
	nbh4.append(Radiobutton(fra[0],text="4 (15')",variable=nbhHISTO1,value=4,bg='lightyellow'))
	nbh4[0].place(x=0,y=80)
	nbh6.append(Radiobutton(fra[0],text="6 (10')",variable=nbhHISTO1,value=6,bg='lightyellow'))
	nbh6[0].place(x=0,y=100)

	if flagBME == 2:	#2 capteurs
		can3 = Canvas(fen1,bg='lightyellow',bd=1)
		can3.pack(expand=YES,fill=BOTH)
		can3.configure(relief='solid',width=480,height=230)
		can3.place(x=500,y=5)
		
		tx=5
		ty=5
		labP1.append(Label(can3,text='Pression:',bg='lightyellow',fg='blue',font=('Arial',12)))
		labP1[1].place(x=tx,y=ty+2)
		labCaptP1.append(Label(can3,bg='lightyellow',fg='blue',font=('Arial',18)))
		labCaptP1[1].place(x=tx+95,y=ty)
		labInf.append(Label(can3,text='Capteur',bg='lightyellow',fg='black',font=('Arial',12,'bold')))
		labInf[1].place(x=260,y=ty+2)

		ty+=30
		labP2.append(Label(can3,text='Pression:',bg='lightyellow',fg='blue',font=('Arial',12)))
		labP2[1].place(x=tx,y=ty+2)
		labCaptP2.append(Label(can3,bg='lightyellow',fg='blue',font=('Arial',18)))
		labCaptP2[1].place(x=tx+95,y=ty)
		
		ty+=30
		labHU.append(Label(can3,text='Humidité Rel:',bg='lightyellow',fg='blue',font=('Arial',12)))
		labHU[1].place(x=tx,y=ty+2)
		labCaptH.append(Label(can3,bg='lightyellow',fg='blue',font=('Arial',18)))
		labCaptH[1].place(x=tx+95,y=ty)
		labCorT.append(Label(can3,text='CorTemp',bg='lightyellow',fg='black',font=('Arial',10)))
		labCorT[1].place(x=260,y=ty)
		EntreeCorT.append(Spinbox(can3,from_=-5,to=5,textvariable=corT2,width=3))
		EntreeCorT[1].place(x=330,y=ty,height=25)
		labAlaT.append(Label(can3,text='Alarme # T',bg='lightyellow',fg='black',font=('Arial',10)))
		labAlaT[1].place(x=260,y=ty+30)
		EntreeAlaT.append(Spinbox(can3,from_=-20,to=30,textvariable=AlaT2,width=3))
		EntreeAlaT[1].place(x=330,y=ty+30,height=25)
	
		ty+=30
		labT.append(Label(can3,text='Température:',bg='lightyellow',fg='blue',font=('Arial',12)))
		labT[1].place(x=tx,y=ty)
		labCaptT.append(Label(can3,bg='lightyellow',fg='blue',font=('Arial',18)))
		labCaptT[1].place(x=tx+95,y=ty)

		ty+=30
		labH.append(Label(can3,text='Heure:',bg='lightyellow',fg='blue',font=('Arial',12)))
		labH[1].place(x=tx,y=ty+2)
		labHeure.append(Label(can3,bg='lightyellow',fg='blue',font=('Arial',18)))
		labHeure[1].place(x=tx+95,y=ty)
		
		ty+=35
		labLOC.append(Label(can3,text='Localisation:',bg='lightyellow',fg='blue',font=('Arial',12)))
		labLOC[1].place(x=tx,y=ty)
		EntreeLOC.append(Entry(can3,textvariable=Loca2,font=("Arial",10),width=20,bg="lightyellow"))
		EntreeLOC[1].place(x=tx+105,y=ty)
		EntreeLOC[1].config(relief='flat')
		
		ty+=30
		can3.create_line(10,ty,470,ty,width=2,fill='grey')
		labMIN.append(Label(can3,text='MIN: ----',bg='lightyellow',fg='green',font=('Arial',12)))
		labMIN[1].place(x=10,y=ty+7)
		labDmin.append(Label(can3,text='----',bg='lightyellow',fg='green',font=('Arial',10)))
		labDmin[1].place(x=100,y=ty+2)
		labHmin.append(Label(can3,text='----',bg='lightyellow',fg='green',font=('Arial',10)))
		labHmin[1].place(x=100,y=ty+17)
		
		labMAX.append(Label(can3,text='MAX: ----',bg='lightyellow',fg='green',font=('Arial',12)))
		labMAX[1].place(x=190,y=ty+7)
		labDmax.append(Label(can3,text='----',bg='lightyellow',fg='green',font=('Arial',10)))
		labDmax[1].place(x=280,y=ty+2)
		labHmax.append(Label(can3,text='----',bg='lightyellow',fg='green',font=('Arial',10)))
		labHmax[1].place(x=280,y=ty+17)

		bouRAZ.append(Button(can3,text="RAZ-2",command=RAZ2,font=('Arial',10)))
		bouRAZ[1].place(x=390,y=ty+8,height=20)

		fra.append(LabelFrame(can3,text="HISTO",width=80,height=145,borderwidth=1,relief='solid',bg='lightyellow',fg='black',font=('Arial',10)))
		fra[1].place(x=390,y=8)
		CheckHISTO.append(Checkbutton(fra[1],text="Histo",variable=chkHISTO2,bg='lightyellow'))
		CheckHISTO[1].place(x=2,y=2)
		labNBH.append(Label(fra[1],text='Nb/Heure',bg='lightyellow',fg='black',font=('Arial',10)))
		labNBH[1].place(x=2,y=22)
		nbh1.append(Radiobutton(fra[1], text="1 (60')",variable=nbhHISTO2,value=1,bg='lightyellow'))
		nbh1[1].place(x=0,y=40)
		nbh2.append(Radiobutton(fra[1], text="2 (30')",variable=nbhHISTO2,value=2,bg='lightyellow'))
		nbh2[1].place(x=0,y=60)
		nbh4.append(Radiobutton(fra[1], text="4 (15')",variable=nbhHISTO2,value=4,bg='lightyellow'))
		nbh4[1].place(x=0,y=80)
		nbh6.append(Radiobutton(fra[1], text="6 (10')",variable=nbhHISTO2,value=6,bg='lightyellow'))
		nbh6[1].place(x=0,y=100)
	fen1.update()


#=====================================================================================
fen1 = Tk()
fen1.resizable(width=False, height=False)
fen1.protocol("WM_DELETE_WINDOW", Fermer)

Cycle=IntVar()
corT1=StringVar()
AlaT1=StringVar()
chkHISTO1=IntVar()
nbhHISTO1=StringVar()
Loca1=StringVar()
corT2=StringVar()
AlaT2=StringVar()
chkHISTO2=IntVar()
nbhHISTO2=StringVar()
Loca2=StringVar()

FichierConf=sys.path[0] + "/Thermo2-201.conf"

f=sys.path[0] + "/ThermoCHE.txt"
if os.path.exists(f):
	with open(f,'r') as nF:
		l=nF.readlines()
	nF.close()
else:
	msg="Pas de Fichier " + f
	messagebox.showwarning("ATTENTION",msg)
	exit(0)

#Numero du Raspi dans ThermoCHE.txt pour déterminer le chemin des datas
if len(sys.argv) >= 2:
	nbZ = int(sys.argv[1])
else:
	msg="Manque N° du PI" + "\n"
	msg=msg + "En Argument de ligne de commande"
	messagebox.showwarning("ATTENTION",msg)
	exit(0)
#Enleve le N° et fin de ligne
che=l[nbZ][:-1].split(",")
che1=che[1] + "HistoThermo1/"
che2=che[1] + "HistoThermo2/"
#Création des sous-dossiers si besoin
try:
	os.mkdir(che1)
except:
	pass
try:
	os.mkdir(che2)
except:
	pass

if os.path.exists(che1) and os.path.exists(che2):
	FichDAT1=che1 + "Thermo.dat"
	FichDAT2=che2 + "Thermo.dat"
	FichMM1=che1 + "ThermoMM.dat"
	FichMM2=che2 + "ThermoMM.dat"
else:
	msg="Mauvais Chemin Data " + str(nbZ) + "\n"
	msg=msg + che1 + "\n"
	msg=msg + che2
	messagebox.showwarning("ATTENTION",msg)
	exit(100)

flagRUN=True
Tmin1=[50,"",""]
Tmax1=[-50,"",""]
Tmin2=[50,"",""]
Tmax2=[-50,"",""]
unitP="hPa"
CycleHISTO1=0
nbhHISTO1.set(4)
CycleHISTO2=0
nbhHISTO2.set(4)
Loca1.set("Description1 ?")
Loca2.set("Description2 ?")

Tscreen=Taillescreen()
scrW=int(Tscreen[0])
scrH=int(Tscreen[1])

config_GPIO()

LIRE_Config()

if flagBME == 0:
	Dessine_Principale(500,310)
	labInf[0].config(text="????")
	labCaptP2[0].config(text="FERMETURE")
	fen1.update()
	sleep(5)
	Fermer()
elif flagBME == 1:		#BME280 (0x76-118)
	Dessine_Principale(500,285)
	labInf[0].config(text="BME280-" + str(hex(Capteur1.Ad)))
elif flagBME == 2:		#BME280 (0x77-119)
	Dessine_Principale(995,285)
	labInf[0].config(text="BME280-" + str(hex(Capteur1.Ad)))
	labInf[1].config(text="BME280-" + str(hex(Capteur2.Ad)))

t=time.time()
tv=t
tg1=t
tg2=t

while flagRUN and flagBME:
	#Recharge pour la Date
	FichHISTO1=che1 + datetime.now().strftime('%Y') + "_" + Get_Nom() + "_Thermo.dat"
	FichHISTO2=che2 + datetime.now().strftime('%Y') + "_" + Get_Nom() + "_Thermo.dat"
	Voyant('magenta')

	if flagBME:
		if time.time() > tg1+Cycle.get()*CycleHISTO1 and chkHISTO1.get():
			"""Enregistre en HISTO tous les x cycles si valide"""
			Lire_BME280_1(True)
			tg1=time.time()
		else:
			Lire_BME280_1(False)

		if flagBME == 2:
			if time.time() > tg2+Cycle.get()*CycleHISTO2 and chkHISTO2.get():
				Lire_BME280_2(True)
				tg2=time.time()
			else:
				Lire_BME280_2(False)
		Voyant('red')
		sleep(1)

	bouENR.config(fg='blue')

	while flagRUN and time.time() < t+Cycle.get():
		try:
			#Voyant clignotte
			if time.time() > tv+1:
				Voyant('yellow')
				tv=time.time()
			else:
				Voyant('green')
			sleep(0.5)
		except:
			Fermer()
	t=time.time()

Fermer()
